==> DeepBrainSeg-0.1.3.tar.gz: DeepBrainSeg-0.1.3/README.md <==
# Ensemble-of-Deep-2D-and-3D-Fully-Convolutional-Neural-Network-for-Brain-Tumor-Segmentation

[![Build Status](https://travis-ci.org/koriavinash1/DeepBrainSeg.svg?branch=master)](https://travis-ci.org/koriavinash1/DeepBrainSeg)
[![PyPI version](https://badge.fury.io/py/DeepBrainSeg.svg)](https://badge.fury.io/py/DeepBrainSeg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


This repo utilize a ensemble of 2-D and 3-D fully convoultional neural network (CNN) for segmentation of the brain tumor and its constituents from multi modal Magnetic Resonance Images (MRI). The dense connectivity pattern used in the segmentation network enables effective reuse of features with lesser number of network parameters. On the BraTS validation data, the segmentation network achieved a whole tumor, tumor core and active tumor dice of 0.89, 0.76, 0.76 respectively.

# Pipeline

![pipeline](./imgs/pipeline.png)

# Results

![Results](./imgs/results.png)

### For training code please refer this [repo](https://github.com/koriavinash1/BraTs2018)

### Basic usage

>> for data in BraTs format
```
from DeepBrainSeg import deepSeg
segmentor = deepSeg(quick=True)
segmentor.get_segmentation_brats(path)
```

>> for other formats
```
from DeepBrainSeg import deepSeg
t1_path = 
t2_path = 
t1ce_path = 
flair_path = 

segmentor = deepSeg(quick=True)
segmentor.get_segmentation(t1_path, t2_path, t1ce_path, flair_path, save = True)
```


# Steps followed for inference:

+ Our algorithm makes use of ANTs framework for mask generation. First call deepSeg class build ANTs framework locally in /tmp/DeepBrainSeg

+ Final segmentation is the result of ensemble of 4 different models:
    
    + ABLNet (modelABL.py, Air brain Lesion Network)

    + 3DBrainNet (model3DBNET.py, 3D multiresolution CNN)
    
    + Tiramisu2D (modelTis2D.py, 57 layered 2D CNN)
    
    + Tiramisu 3D (modelTir3D.py, 57 layered 3D CNN)

+ Extensive documentation will be uploaded soon, along with transfer learning framework

+ More details about network architecture and training procedure can be found [here](https://link.springer.com/chapter/10.1007/978-3-030-11726-9_43)


# Citation

If you use some of our work, please cite our work:

```
@inproceedings{kori2018ensemble,
  title={Ensemble of Fully Convolutional Neural Network for Brain Tumor Segmentation from Magnetic Resonance Images},
  author={Kori, Avinash and Soni, Mehul and Pranjal, B and Khened, Mahendra and Alex, Varghese and Krishnamurthi, Ganapathy},
  booktitle={International MICCAI Brainlesion Workshop},
  pages={485--496},
  year={2018},
  organization={Springer}
}
``` 

## Contact 

* Avinash Kori (avinashgkori@smail.iitm.ac.in or koriavinash1@gmail.com)

==> DeepBrainSeg-0.1.7.tar.gz: DeepBrainSeg-0.1.7/README.md <==
# Ensemble-of-Deep-2D-and-3D-Fully-Convolutional-Neural-Network-for-Brain-Tumor-Segmentation

[![Build Status](https://travis-ci.org/koriavinash1/DeepBrainSeg.svg?branch=master)](https://travis-ci.org/koriavinash1/DeepBrainSeg)
[![PyPI version](https://badge.fury.io/py/DeepBrainSeg.svg)](https://badge.fury.io/py/DeepBrainSeg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


This repo utilize a ensemble of 2-D and 3-D fully convoultional neural network (CNN) for segmentation of the brain tumor and its constituents from multi modal Magnetic Resonance Images (MRI). The dense connectivity pattern used in the segmentation network enables effective reuse of features with lesser number of network parameters. On the BraTS validation data, the segmentation network achieved a whole tumor, tumor core and active tumor dice of 0.89, 0.76, 0.76 respectively.

# Pipeline

![pipeline](./imgs/pipeline.png)

# Results

![Results](./imgs/results.png)

### For training code please refer this [repo](https://github.com/koriavinash1/BraTs2018)


#### python version: 3.5
#### installation: ```pip install DeepBrainSeg```

<hline>

### Basic usage

> for data in BraTs format
```
from DeepBrainSeg import deepSeg
segmentor = deepSeg(quick=True)
segmentor.get_segmentation_brats(path)
```

<hline>

> for other formats
```
from DeepBrainSeg import deepSeg
t1_path = 
t2_path = 
t1ce_path = 
flair_path = 

segmentor = deepSeg(quick=True)
segmentor.get_segmentation(t1_path, t2_path, t1ce_path, flair_path, save = True)
```

<hline>

# Steps followed for inference:

+ Our algorithm makes use of ANTs framework for mask generation. First call deepSeg class build ANTs framework locally in /tmp/DeepBrainSeg

+ Final segmentation is the result of ensemble of 4 different models:
    
    + ABLNet (modelABL.py, Air brain Lesion Network)

    + 3DBrainNet (model3DBNET.py, 3D multiresolution CNN)
    
    + Tiramisu2D (modelTis2D.py, 57 layered 2D CNN)
    
    + Tiramisu 3D (modelTir3D.py, 57 layered 3D CNN)

+ Extensive documentation will be uploaded soon, along with transfer learning framework

+ More details about network architecture and training procedure can be found [here](https://link.springer.com/chapter/10.1007/978-3-030-11726-9_43)


# Citation

If you use some of our work, please cite our work:

```
@inproceedings{kori2018ensemble,
  title={Ensemble of Fully Convolutional Neural Network for Brain Tumor Segmentation from Magnetic Resonance Images},
  author={Kori, Avinash and Soni, Mehul and Pranjal, B and Khened, Mahendra and Alex, Varghese and Krishnamurthi, Ganapathy},
  booktitle={International MICCAI Brainlesion Workshop},
  pages={485--496},
  year={2018},
  organization={Springer}
}
``` 

## Contact 

* Avinash Kori (avinashgkori@smail.iitm.ac.in or koriavinash1@gmail.com)
